@@ -21,6 +21,8 @@
 
 **************************************************************************** */
 
+#include "lokalize_debug.h"
+
 #include "editortab.h"
 #include "editorview.h"
 #include "catalog.h"
@@ -36,12 +38,10 @@
 #include <kmessagebox.h>
 #include <kreplacedialog.h>
 #include <kreplace.h>
-#include <kdemacros.h>
 
 #include <sonnet/backgroundchecker.h>
 #include <sonnet/dialog.h>
 
-#include <QDebug>
 #include <QTimer>
 #include <QPointer>
 
@@ -163,13 +163,13 @@ static void calcOffsetWithAccels(const QString& data, int& offset, int& length)
 {
     int i=0;
     for (;i<offset;++i)
-        if (KDE_ISUNLIKELY( data.at(i)=='&' ))
+        if (Q_UNLIKELY( data.at(i)=='&' ))
             ++offset;
 
     //if & is inside highlighted word
     int limit=offset+length;
     for (i=offset;i<limit;++i)
-        if (KDE_ISUNLIKELY( data.at(i)=='&' ))
+        if (Q_UNLIKELY( data.at(i)=='&' ))
         {
             ++length;
             limit=qMin(data.size(),offset+length);//just safety
@@ -240,7 +240,7 @@ void EditorTab::findNext(const DocPosition& startingPos)
     Catalog& catalog=*m_catalog;
     KFind& find=*m_find;
 
-    if (KDE_ISUNLIKELY( catalog.numberOfEntries()<=startingPos.entry ))
+    if (Q_UNLIKELY( catalog.numberOfEntries()<=startingPos.entry ))
         return;//for the case when app wasn't able to process event before file close
 
     bool anotherEntry=_searchingPos.entry!=m_currentPos.entry;
@@ -411,7 +411,7 @@ void EditorTab::replaceNext(const DocPosition& startingPos)
     int flag=1;
     bool ignoreaccels=m_replace->options()&IGNOREACCELS;
     bool includenotes=m_replace->options()&INCLUDENOTES;
-    qWarning()<<"includenotes"<<includenotes;
+    qCWarning(LOKALIZE_LOG)<<"includenotes"<<includenotes;
     int switchOptions=DocPosition::Target|(includenotes*DocPosition::Comment);
     while (flag)
     {
@@ -580,8 +580,8 @@ void EditorTab::spellcheckNext()
     {
         if (!switchNext(m_catalog,_spellcheckPos))
         {
-            qWarning()<<_spellcheckStartPos.entry;
-            qWarning()<<_spellcheckStartPos.form;
+            qCWarning(LOKALIZE_LOG)<<_spellcheckStartPos.entry;
+            qCWarning(LOKALIZE_LOG)<<_spellcheckStartPos.form;
             bool continueFromStart=
                 !(_spellcheckStartPos.entry==0 && _spellcheckStartPos.form==0)
                 && KMessageBox::questionYesNo(this,i18n("Lokalize has reached end of document. Do you want to continue from start?"),
